import re
from collections import Counter
import textdistance
import pandas as pd
import os


current_directory = os.path.dirname(os.path.abspath(__file__))
file_path = os.path.join(current_directory, 'autocorrect book.txt')

print("Attempting to open file at:", file_path)
# Get the absolute path to the file



words = []

with open(file_path, 'r', encoding='utf-8') as f:
    data = f.read().lower()
    words = re.findall('\w+', data)
    words += words

# Create a set of unique words and a frequency dictionary
V = set(words)
words_freq_dict = Counter(words)
Total = sum(words_freq_dict.values())
probs = {}

for k in words_freq_dict.keys():
    probs[k] = words_freq_dict[k] / Total

def get_suggestions(keyword):
    keyword = keyword.lower()
    if keyword:
        similarities = [1 - textdistance.Jaccard(qval=len(keyword)-1).distance(v, keyword) for v in words_freq_dict.keys()]
        df = pd.DataFrame.from_dict(probs, orient='index').reset_index()
        df.columns = ['Word', 'Prob']
        df['Similarity'] = similarities
        suggestions = df.sort_values(['Similarity', 'Prob'], ascending=False).head(10)['Word'].tolist()
        return suggestions
    else:
        return []

if __name__ == '__main__':
    
        keyword = input("Enter a word: ")
        suggestions = get_suggestions(keyword)
        print("Suggestions:", suggestions)



from setuptools import setup, find_packages

setup(
    name='matrecord_suggestion',
    version='0.2',
    packages=find_packages(),
    package_data={'matrecord_suggestion': ['autocorrect book.txt']},
    author='Nida Deshmukh',
    author_email='nidadeshmukh7@email.com',
    description='A Python package for providing word suggestions.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    license='MIT',
    url='https://github.com/Nida-Deshmukh123/matrecord_suggestion',
    install_requires=[
        'textdistance',
        'pandas'
    ],
    classifiers=[
        
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3 :: Only',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
